NAME
Sisimai::MTA::Postfix - bounce mail parser class for Postfix.
SYNOPSIS
use Sisimai::MTA::Postfix;
DESCRIPTION
Sisimai::MTA::Postfix parses a bounce email which created by Postfix. Methods in the module are called from only Sisimai::Message.
CLASS METHODS
description()
description() returns description string of this module.
print Sisimai::MTA::Postfix->description;
smtpagent()
smtpagent() returns MTA name.
print Sisimai::MTA::Postfix->smtpagent;
scan( header data, reference to body string)
scan() method parses a bounced email and return results as a array reference. See Sisimai::Message for more details.
AUTHOR
azumakuniyuki
COPYRIGHT
Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
LICENSE
This software is distributed under The BSD 2-Clause License.